@@ -10,6 +10,7 @@ def get_content_type_for_model(obj):
     from django.contrib.contenttypes.models import ContentType
     return ContentType.objects.get_for_model(obj, for_concrete_model=False)
 
+
 '''
 changed_field = [
     {
@@ -27,28 +28,29 @@ changed_field = [
 
 def changed_message(changed_field, old, new):
     message = ''
+    new = new.__dict__
     for i in changed_field:
         if "changed" in i:
             if "fields" in i["changed"]:
                 for field in i["changed"]["fields"]:
                     try:
                         message += f"field: {field}"
-                        old_field = eval('old["fields"]["' + field + '"]')
-                        new_field = eval('new.' + field)
-                        message += f", old: {str(old_field).encode('utf-8', 'ignore')}, new: {str(new_field).encode('utf-8', 'ignore')}\n"
-                    except:
-                        pass
+                        old_field = old[field]
+                        new_field = new[field]
+                        message += f", old: {str(old_field)}, new: {str(new_field)}\n"
+                    except Exception as e:
+                        print(str(e))
         if "added" in i:
             for key, value in i["added"].items():
                 try:
                     message += f"added: {key} - {value}\n"
                 except:
                     pass
-    return message.encode('utf-8', 'ignore')
+
+    return message + '\n' + str(changed_field)
 
 
 class CustomModelAdmin(admin.ModelAdmin):
-
     old_instance = {}
 
     def save_model(self, request, obj, form, change):
@@ -57,10 +59,7 @@ class CustomModelAdmin(admin.ModelAdmin):
         """
         try:
             old_obj = obj._meta.model.objects.get(id=obj.id)
-            old_obj_str = serializers.serialize('json', [old_obj, ])
-            old_obj_str = old_obj_str.replace("null", "None").replace("false", "False").replace("true", "True")
-            old_obj_json = eval(old_obj_str)[0]
-            self.old_instance = old_obj_json
+            self.old_instance = old_obj.__dict__
         except Exception as e:
             pass
         obj.save()
@@ -70,10 +69,8 @@ class CustomModelAdmin(admin.ModelAdmin):
         Given a model instance delete it from the database.
         """
         try:
-            old_obj_str = serializers.serialize('json', [obj, ])
-            old_obj_str = old_obj_str.replace("null", "None").replace("false", "False").replace("true", "True")
-            old_obj_json = eval(old_obj_str)[0]
-            self.old_instance = old_obj_json
+
+            self.old_instance = obj.__dict__
         except:
             pass
         obj.delete()
